
# User Guide

```{toctree}
:caption: Get started

installation
```

```{toctree}
:caption: Data

data-fundamentals
data-practicum
```

```{toctree}
:caption: Models

linear-funcs
choice-models
compute-engines
```


```{toctree}
:caption: References

bibliography
```
